<?php
namespace Teknisa\EST\Modules\EstoqueCego\Controllers;

use Teknisa\EST\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO;

class Est91000ProgramacaoDoInventarioCegoController extends TeknisaCrud {

    protected $dataSourceName = "inventestcego_paramfilial_paramgeral_filioper";
    protected $parameterBagColumns = ["CDFILIAL","DTINICIAL","DTFINAL","IDSITESTCEGO","CDOPERADOR"];

    protected $Est91000ProgramacaoDoInventarioCegoService;
    protected $dataSourceManager;
    protected $environment;
    protected $crudService;
    
    public function __construct($crudService,$parameterBag, $Est91000Service,$dataSourceManager,$environment) {

        $this->crudService = $crudService;
        $this->dataSourceManager = $dataSourceManager;
        $this->environment = $environment;
        $this->Est91000ProgramacaoDoInventarioCegoService = $Est91000Service;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $this->Est91000ProgramacaoDoInventarioCegoService->formatMutipleFilialCode($conditions);
        
        $newFilterCriteria = new FilterCriteria($this->dataSourceName, $conditions);
        $filter = new DTO\Request\Filter($newFilterCriteria, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
        
        parent::find($filter, $response);
    }
    
    public function saveProducts(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $this->Est91000ProgramacaoDoInventarioCegoService->insertLote($row);
            $this->Est91000ProgramacaoDoInventarioCegoService->saveProducts($row);
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function checkInventoryHandler(Request $request, Response $response) {
        try {
            $status = [];
            $row = $request->getRow(); 
            if($row['FIRSTTEST']){
                $inventoryInfo = $this->Est91000ProgramacaoDoInventarioCegoService->checkInventoryActualDate($row);
                if(!empty($inventoryInfo)){
                    //verficar loop
                    foreach($inventoryInfo as $info){
                        if ($info["IDSITESTCEGO"] === 'ED' ||
                            $info["IDSITESTCEGO"] === 'DG' ||
                            $info["IDSITESTCEGO"] === 'AP'){
                            $status["programado"] = "B";
                            break;
                        }else{
                            $status["programado"] = "P";
                        }
                    };
                }else{
                    $status["programado"] = "N";
                }
            }else{
                $this->Est91000ProgramacaoDoInventarioCegoService->deleteAllInventory($row);
            }
            
            $status["feriado"] = $this->Est91000ProgramacaoDoInventarioCegoService->checkHolidays($row);
            
            $response->addDataSet(new DataSet("filialParams", $status));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function generateInventory(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            
            foreach($row['CDFILIAL'] as $filial){
                
                $complementaryInfo = $this->Est91000ProgramacaoDoInventarioCegoService->getProductsInfo($row,$filial);
                //save inventories
                $InventoriesArrayToSave = $this->Est91000ProgramacaoDoInventarioCegoService->getInventoriesToSave($row,$filial,$complementaryInfo);
    			$newDatasetToSave = new DataSet('inventestcego', $InventoriesArrayToSave);
    			$newRequestToSave = new DTO\Request\DataSet($newDatasetToSave, '', '', '');
    			$inventoryToSave = $this->crudService->getRowsToSave($newRequestToSave, "inventestcego");
    			$dataSetToSave = new DataSet("inventestcego", $inventoryToSave);
    			
    			$this->dataSourceManager->persist($dataSetToSave);
    			
    			//save items
                $ItemsArrayToSave = $this->Est91000ProgramacaoDoInventarioCegoService->getProductsToSave($row,$filial,$complementaryInfo);
    			$newDatasetToSave = new DataSet('iteminventcego', $ItemsArrayToSave);
    			$newRequestToSave = new DTO\Request\DataSet($newDatasetToSave, '', '', '');
    			$itemsToSave = $this->crudService->getRowsToSave($newRequestToSave, "iteminventcego");
    			$dataSetToSave = new DataSet("iteminventcego", $itemsToSave);
    			
			    $this->dataSourceManager->persist($dataSetToSave);
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}
