/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0006_DENSTPO_USR_EXPORTAPEDOL_DENADAI.sql                            */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a possibilitar que os pedidos do OL                    */
/* (Operador Logstico) geradas pelo sistema da Teknisa sejam importadas      */
/* no sistema da Microsiga e, para isso, a procedure alimentar duas tabelas  */
/* intermedirias entre os dois sistemas (tabelas pertencentes ao banco de    */
/* dados do sistema da Microsiga).                                            */
/* Criao:                                                                   */
/* 26/08/2008 - Raquel Cunha                                                  */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_EXPORTAPEDOL_DENADAI IS
   V_FILIAL VARCHAR(10);
   V_FORMPGTO VARCHAR(3);
   V_FORNECEDOR VARCHAR(21);
   V_FILENT VARCHAR(10);
   V_NUM6 VARCHAR(10);
   V_NUM7 VARCHAR(10);
   V_NRSEQ VARCHAR(2);
   V_CUSTO FLOAT;
   V_NRTIPOCUST VARCHAR2(2);
   V_VALOR FLOAT;
   V_PRODINTE VARCHAR(20);
   V_PRODESTO VARCHAR(10);
   V_CULTLIST FLOAT;
BEGIN
   V_NRSEQ := '01';
   FOR C_PEDOLEXPORT IN
      (SELECT CDFILDEST, CDFILLANC, NRPEDEXOL,
              DTPEDEXOL, CDFILIOPELOG, NRINSJTREXOL,
              CDEMPRESA
       FROM PEDIDOEXOL
       WHERE USR_DTEXPORTA IS NULL
       ORDER BY CDFILDEST, CDFILLANC, NRPEDEXOL)
   LOOP
      FOR C_ITEMPEDEXOL IN
         (SELECT CDFILDEST, CDFILLANC, NRPEDEXOL,
                 CDMARCA, CDPRODUTO, DTPROGENPEOL,
                 CDOPERBAIXA, DTBAIXTMPEOL, QTPROGENPEOL
          FROM ITEMPEDEXOL
          WHERE CDFILDEST = C_PEDOLEXPORT.CDFILDEST
            AND CDFILLANC = C_PEDOLEXPORT.CDFILLANC
            AND NRPEDEXOL = C_PEDOLEXPORT.NRPEDEXOL
          ORDER BY CDFILDEST, CDFILLANC, NRPEDEXOL, CDMARCA, CDPRODUTO, DTPROGENPEOL)
      LOOP
         SELECT MAX(CDGRUPFILI)
         INTO V_FILIAL
         FROM FILGRUPFILI
         WHERE CDFILIAL = C_PEDOLEXPORT.CDFILLANC
           AND USR_IDPROTHEUS = 'S';

         SELECT MAX(CDFORMPGTO),
                MAX(CDFORNECED)
         INTO V_FORMPGTO,
              V_FORNECEDOR
         FROM FORNECEDOR
         WHERE NRINSJURFORN = C_PEDOLEXPORT.NRINSJTREXOL;

         SELECT MAX(CDGRUPFILI)
         INTO V_FILENT
         FROM FILGRUPFILI
         WHERE CDFILIAL = C_PEDOLEXPORT.CDFILDEST
           AND USR_IDPROTHEUS = 'S';

         SELECT MAX(W6_NUM)
         INTO V_NUM6
         FROM USR_ZW6
         WHERE W6_FILIAL = SUBSTR(V_FILIAL, 9, 2)
           AND W6_NUM = SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6);

         IF V_NUM6 IS NULL THEN
            INSERT INTO USR_ZW6
                (W6_EMPRESA, W6_FILIAL, W6_NUM,
                 W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI,
                 W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
            VALUES
                (SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                 SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6), SUBSTR(V_FORNECEDOR, 1, 14),
                 SUBSTR(V_FILENT, 9, 2), V_FORMPGTO, 'N', '1',
                 TO_CHAR(TRUNC(SYSDATE), 'DDMMYYYY'),
                 TO_CHAR(SYSDATE, 'HH24MI'), NULL, '');
         END IF;

         SELECT MAX(CDPRODINTE),
                MAX(CDPRODESTO)
         INTO V_PRODINTE,
              V_PRODESTO
         FROM PRODUTO
         WHERE CDPRODUTO = C_ITEMPEDEXOL.CDPRODUTO;

         SELECT MAX(CDTIPCUSTEST)
         INTO V_NRTIPOCUST
         FROM PARAMFILIAL
         WHERE CDFILIAL = C_PEDOLEXPORT.CDFILDEST;

         IF V_NRTIPOCUST IS NULL THEN
            V_NRTIPOCUST := '03';
         END IF;

         V_CUSTO := CUSTO_PRODUTO(C_PEDOLEXPORT.CDFILDEST, V_PRODESTO,
                                  V_NRTIPOCUST, C_ITEMPEDEXOL.DTPROGENPEOL, SYSDATE);

         V_CULTLIST := CUSTO_PRODUTO(C_PEDOLEXPORT.CDFILIOPELOG, V_PRODESTO,
                                     '06', C_ITEMPEDEXOL.DTPROGENPEOL, SYSDATE);

         V_VALOR := C_ITEMPEDEXOL.QTPROGENPEOL*V_CUSTO;

         SELECT MAX(W7_NUM)
         INTO V_NUM7
         FROM USR_ZW7
         WHERE W7_FILIAL = SUBSTR(V_FILIAL, 9, 2)
           AND W7_NUM = SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6);

         IF V_NUM7 IS NULL THEN
            INSERT INTO USR_ZW7
                 (W7_EMPRESA, W7_FILIAL, W7_NUM,
                  W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                  W7_PRCVEN, W7_PRUNIT, W7_VALOR, W7_TPEDI,
                  W7_DTGRV, W7_HRGRV, W7_DTIMP, W7_HRIMP)
            VALUES
                 (SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                  SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6),
                  SUBSTR(V_FORNECEDOR, 1, 14), V_NRSEQ, SUBSTR(V_PRODINTE, 1, 15),
                  SUBSTR(V_FILENT, 9, 2), C_ITEMPEDEXOL.QTPROGENPEOL,
                  V_CUSTO, V_CULTLIST, V_VALOR, '1', TO_CHAR(TRUNC(SYSDATE), 'DDMMYYYY'),
                  TO_CHAR(SYSDATE, 'HH24MI'), NULL, '');
            V_NRSEQ := LPAD(RTRIM(TO_CHAR(TO_NUMBER(RTRIM(V_NRSEQ))+ 1)),2,'0');
         END IF;
      END LOOP;

      UPDATE PEDIDOEXOL
      SET USR_DTEXPORTA = SYSDATE
      WHERE CDFILDEST = C_PEDOLEXPORT.CDFILDEST
        AND CDFILLANC = C_PEDOLEXPORT.CDFILLANC
        AND NRPEDEXOL = C_PEDOLEXPORT.NRPEDEXOL;

      V_NRSEQ := '01';
   END LOOP;
END;
/
